from enum import Enum


class RolesListNonFixturesRole(str, Enum):
    ASSISTANT_REFEREE_1 = "ASSISTANT_REFEREE_1"
    ASSISTANT_REFEREE_2 = "ASSISTANT_REFEREE_2"
    CAPTAIN = "CAPTAIN"
    CAPTAIN_VICE = "CAPTAIN_VICE"
    CEO = "CEO"
    CLUB_IT_OFFICER = "CLUB_IT_OFFICER"
    CLUB_OFFICIAL = "CLUB_OFFICIAL"
    CLUB_OFFICIAL_ASSISTANT = "CLUB_OFFICIAL_ASSISTANT"
    COACH = "COACH"
    COACH_ASSISTANT = "COACH_ASSISTANT"
    COACH_ASSISTANT_HEAD = "COACH_ASSISTANT_HEAD"
    COACH_ASSOCIATE_HEAD = "COACH_ASSOCIATE_HEAD"
    COACH_DEVELOPMENT = "COACH_DEVELOPMENT"
    COACH_HEAD = "COACH_HEAD"
    COACH_HEAD_INTERIM = "COACH_HEAD_INTERIM"
    COACH_OTHER = "COACH_OTHER"
    COACH_SC = "COACH_SC"
    COACH_SENIOR = "COACH_SENIOR"
    COACH_SPECIALIST = "COACH_SPECIALIST"
    COMMISSIONER = "COMMISSIONER"
    COMMITTEE = "COMMITTEE"
    CREW_CHIEF = "CREW_CHIEF"
    DELEGATE = "DELEGATE"
    DIRECTOR = "DIRECTOR"
    DOCTOR = "DOCTOR"
    GENERAL = "GENERAL"
    GROUNDSKEEPER = "GROUNDSKEEPER"
    JUDGE_SCORING = "JUDGE_SCORING"
    JUDGE_TIMING = "JUDGE_TIMING"
    LIAISON_OFFICER = "LIAISON_OFFICER"
    MANAGER = "MANAGER"
    MATCH_LIAISON = "MATCH_LIAISON"
    MATCH_OFFICIAL = "MATCH_OFFICIAL"
    MATCH_SUPERVISOR = "MATCH_SUPERVISOR"
    MEDIA_OFFICER = "MEDIA_OFFICER"
    MEDICAL_STAFF = "MEDICAL_STAFF"
    OFFICE_STAFF = "OFFICE_STAFF"
    OFFICIAL_A = "OFFICIAL_A"
    OFFICIAL_B = "OFFICIAL_B"
    OFFICIAL_C = "OFFICIAL_C"
    OFFICIAL_D = "OFFICIAL_D"
    OFFICIAL_E = "OFFICIAL_E"
    OTHER = "OTHER"
    PHYSIOTHERAPIST = "PHYSIOTHERAPIST"
    PLAYER_CONTRACT_MANAGER = "PLAYER_CONTRACT_MANAGER"
    PRESIDENT = "PRESIDENT"
    PRESIDENT_VICE = "PRESIDENT_VICE"
    REFEREE = "REFEREE"
    REFEREE_ASSISTANT = "REFEREE_ASSISTANT"
    REFEREE_ASSISTANT_RESERVE = "REFEREE_ASSISTANT_RESERVE"
    REFEREE_LIAISON = "REFEREE_LIAISON"
    REFEREE_OBSERVER = "REFEREE_OBSERVER"
    REFEREE_OBSERVER_LIAISON = "REFEREE_OBSERVER_LIAISON"
    REFEREE_RESERVE = "REFEREE_RESERVE"
    SCOREKEEPER = "SCOREKEEPER"
    SCOREKEEPER_ASSISTANT = "SCOREKEEPER_ASSISTANT"
    SCORER = "SCORER"
    SCORER_ASSISTANT = "SCORER_ASSISTANT"
    SCOUT_1 = "SCOUT_1"
    SCOUT_2 = "SCOUT_2"
    SCOUT_3 = "SCOUT_3"
    SCOUT_SUPERVISOR = "SCOUT_SUPERVISOR"
    SECRETARY = "SECRETARY"
    SHOT_CLOCK_OPERATOR = "SHOT_CLOCK_OPERATOR"
    SPORT_DIRECTOR = "SPORT_DIRECTOR"
    STATISTICIAN = "STATISTICIAN"
    TEAM_COORDINATOR = "TEAM_COORDINATOR"
    TECHNICAL_DELEGATE = "TECHNICAL_DELEGATE"
    TECHNICAL_DELEGATE_ASSISTANT = "TECHNICAL_DELEGATE_ASSISTANT"
    TECHNICAL_OFFICIAL = "TECHNICAL_OFFICIAL"
    TIMEKEEPER = "TIMEKEEPER"
    TIMER = "TIMER"
    TRAINER = "TRAINER"
    TRAINER_ASSISTANT = "TRAINER_ASSISTANT"
    TRANSLATOR = "TRANSLATOR"
    TREASURER = "TREASURER"
    UMPIRE = "UMPIRE"
    UMPIRE_1 = "UMPIRE_1"
    UMPIRE_2 = "UMPIRE_2"
    UMPIRE_MANAGER = "UMPIRE_MANAGER"
    UMPIRE_RESERVE = "UMPIRE_RESERVE"
    UMPIRE_VIDEO = "UMPIRE_VIDEO"
    VIDEO_TECHNICIAN = "VIDEO_TECHNICIAN"
    YOUTH_COORDINATOR = "YOUTH_COORDINATOR"

    def __str__(self) -> str:
        return str(self.value)
