from enum import Enum


class MatchProfilesModelMatchProfileConfigurationMatchRolesItem(str, Enum):
    ASSISTANT_REFEREE_1 = "ASSISTANT_REFEREE_1"
    ASSISTANT_REFEREE_2 = "ASSISTANT_REFEREE_2"
    DELEGATE = "DELEGATE"
    LIAISON_OFFICER = "LIAISON_OFFICER"
    MATCH_LIAISON = "MATCH_LIAISON"
    MATCH_SUPERVISOR = "MATCH_SUPERVISOR"
    OFFICE_STAFF = "OFFICE_STAFF"
    REFEREE = "REFEREE"
    REFEREE_LIAISON = "REFEREE_LIAISON"
    REFEREE_OBSERVER = "REFEREE_OBSERVER"
    REFEREE_OBSERVER_LIAISON = "REFEREE_OBSERVER_LIAISON"
    SCOREKEEPER = "SCOREKEEPER"
    SCOUT_1 = "SCOUT_1"
    SCOUT_2 = "SCOUT_2"
    SCOUT_3 = "SCOUT_3"
    SCOUT_SUPERVISOR = "SCOUT_SUPERVISOR"
    SECRETARY = "SECRETARY"
    TIMEKEEPER = "TIMEKEEPER"
    YOUTH_COORDINATOR = "YOUTH_COORDINATOR"

    def __str__(self) -> str:
        return str(self.value)
