from enum import Enum


class SeasonListStandard(str, Enum):
    APPROVED_TEST_MATCHES = "APPROVED_TEST_MATCHES"
    COMMONWEALTH_GAMES = "COMMONWEALTH_GAMES"
    CONTINENTAL_CHAMPIONSHIP = "CONTINENTAL_CHAMPIONSHIP"
    CONTINENTAL_CHAMPIONSHIP_DIV_2 = "CONTINENTAL_CHAMPIONSHIP_DIV_2"
    CONTINENTAL_CHAMPIONSHIP_DIV_3 = "CONTINENTAL_CHAMPIONSHIP_DIV_3"
    CONTINENTAL_CHAMPIONSHIP_DIV_4 = "CONTINENTAL_CHAMPIONSHIP_DIV_4"
    CONTINENTAL_QUALIFIER = "CONTINENTAL_QUALIFIER"
    ELITE = "ELITE"
    FIH_NATIONS_CUP = "FIH_NATIONS_CUP"
    FIH_OLYMPIC_QUALIFIERS = "FIH_OLYMPIC_QUALIFIERS"
    FIH_PRO_LEAGUE = "FIH_PRO_LEAGUE"
    FIH_WORLD_CUP = "FIH_WORLD_CUP"
    FIH_WORLD_CUP_QUALIFIERS = "FIH_WORLD_CUP_QUALIFIERS"
    FRIENDLY = "FRIENDLY"
    GRASS_ROOT = "GRASS_ROOT"
    HISTORICAL_BASELINE = "HISTORICAL_BASELINE"
    HOCKEY_SERIES_OPEN = "HOCKEY_SERIES_OPEN"
    INTERNATIONAL = "INTERNATIONAL"
    INVITATIONAL_TOURNAMENT = "INVITATIONAL_TOURNAMENT"
    NONCONTINENTAL_CHAMPIONSHIP = "NONCONTINENTAL_CHAMPIONSHIP"
    OLYMPIC = "OLYMPIC"
    OLYMPICS = "OLYMPICS"
    REGION = "REGION"
    TIER2 = "TIER2"
    TIER3 = "TIER3"
    WORLD_CHAMPIONSHIP = "WORLD_CHAMPIONSHIP"
    WORLD_LEAGUE = "WORLD_LEAGUE"
    ZONE_CHAMPIONSHIP = "ZONE_CHAMPIONSHIP"

    def __str__(self) -> str:
        return str(self.value)
