from enum import Enum


class CareerPersonRepresentationalStatisticsModelDisciplineType2Type1(str, Enum):
    INDOOR = "INDOOR"
    OUTDOOR = "OUTDOOR"

    def __str__(self) -> str:
        return str(self.value)
